util

package
v0.0.0-...-0e65dd1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 17, 2015 License: MIT Imports: 7 Imported by: 6

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Base64Safe

func Base64Safe(bts []byte) string

Base64Safe - Makes safe for file paths, removes the forward slash '/' and equals '='

func Invoke

func Invoke(any interface{}, name string, args ...interface{})

Invoke(YourT2{}, "MethodFoo", 10, "abc") Invoke(YourT1{}, "MethodBar")

func IsPathSafe

func IsPathSafe(v string) (bool, int)

func MapHeaderToStruct

func MapHeaderToStruct(m map[string][]string, val interface{}) error

MapToStruct is a way to deserialize a dictionary of strings into a struct

func MapToStruct

func MapToStruct(m map[string]string, val interface{}) error

MapToStruct is a way to deserialize a dictionary of strings into a struct

func NewUid

func NewUid() string

func NoQuotes

func NoQuotes(target string) string

func NotEmpty

func NotEmpty(values ...string) string

func NotNil

func NotNil(values ...interface{}) interface{}

Types

This section is empty.

Jump to