Documentation
¶
Index ¶
- func Base64Safe(bts []byte) string
- func Invoke(any interface{}, name string, args ...interface{})
- func IsPathSafe(v string) (bool, int)
- func MapHeaderToStruct(m map[string][]string, val interface{}) error
- func MapToStruct(m map[string]string, val interface{}) error
- func NewUid() string
- func NoQuotes(target string) string
- func NotEmpty(values ...string) string
- func NotNil(values ...interface{}) interface{}
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Base64Safe ¶
Base64Safe - Makes safe for file paths, removes the forward slash '/' and equals '='
func Invoke ¶
func Invoke(any interface{}, name string, args ...interface{})
Invoke(YourT2{}, "MethodFoo", 10, "abc") Invoke(YourT1{}, "MethodBar")
func IsPathSafe ¶
func MapHeaderToStruct ¶
MapToStruct is a way to deserialize a dictionary of strings into a struct
func MapToStruct ¶
MapToStruct is a way to deserialize a dictionary of strings into a struct
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.